"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitsFormat = require("./units-format");
var Units = require("./units");
/**
 * @module Format
 */
/**
 * Get formatting info from unit
 * @param unit
 */
function getUnitFormat(unit, unitsFormat) {
    if (unitsFormat === void 0) { unitsFormat = UnitsFormat; }
    return unitsFormat[unit.name];
}
exports.getUnitFormat = getUnitFormat;
/**
 * Get all units registered for quantity
 * @param quantity
 */
function getUnitsForQuantity(quantity, unitsFormat, units) {
    if (unitsFormat === void 0) { unitsFormat = UnitsFormat; }
    if (units === void 0) { units = Units; }
    var quantityToUnits = getUnitsPerQuantity(unitsFormat, units);
    var unitsForQuantity = quantityToUnits[quantity.toLowerCase()];
    return unitsForQuantity || [];
}
exports.getUnitsForQuantity = getUnitsForQuantity;
var cache = {
    input: undefined,
    output: undefined
};
function getUnitsPerQuantity(unitsFormat, units) {
    if (cache.input === unitsFormat && cache.output !== undefined) {
        return cache.output;
    }
    var quantityToUnits = {}; // tslint:disable-line
    for (var _i = 0, _a = Object.keys(unitsFormat); _i < _a.length; _i++) {
        var unitKey = _a[_i];
        var unit = units[unitKey];
        var quantityKey = unit.quantity.toLowerCase();
        quantityToUnits[quantityKey] = (quantityToUnits[quantityKey] || []).concat(unit);
    }
    cache = {
        input: unitsFormat,
        output: quantityToUnits
    };
    return quantityToUnits;
}
//# sourceMappingURL=format.js.map