"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitDivide = require("../unit-divide");
var base_units_1 = require("./base-units");
var power_1 = require("./power");
var unit_prefix_1 = require("../unit-prefix");
// tslint:disable:variable-name
/**
 * The derived unit for electric potential difference, electromotive force ( <code>V</code> ).
 * One Volt is equal to the difference of electric potential between two points on a conducting
 * wire carrying a export constant current of one ampere when the power dissipated between the points is one watt.
 * It is named after the Italian physicist Count Alessandro Volta (1745-1827).
 */
exports.Volt = UnitDivide.powerByElectricalCurrent("Volt", power_1.Watt, base_units_1.Ampere);
// ElectricPotential
exports.MilliVolt = unit_prefix_1.Milli("MilliVolt", exports.Volt);
exports.KiloVolt = unit_prefix_1.Kilo("KiloVolt", exports.Volt);
//# sourceMappingURL=electric-potential.js.map