"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitTimes = require("../unit-times");
var Unit = require("../unit");
var base_units_1 = require("./base-units");
var force_1 = require("./force");
var unit_prefix_1 = require("../unit-prefix");
// tslint:disable:variable-name
/**
 * The derived unit for energy, work, quantity of heat ( <code>J</code> ).
 * One joule is the amount of work done when an applied force of 1 newton moves
 * through a distance of 1 metre in the direction of the force.
 * It is named after the English physicist James Prescott Joule (1818-1889).
 */
exports.Joule = UnitTimes.forceByLength("Joule", force_1.Newton, base_units_1.Meter);
// Energy
exports.NewtonMeter = UnitTimes.forceByLength("NewtonMeter", force_1.Newton, base_units_1.Meter);
exports.Kilojoule = unit_prefix_1.Kilo("Kilojoule", exports.Joule);
exports.Megajoule = unit_prefix_1.Mega("Megajoule", exports.Joule);
exports.Btu = Unit.timesNumber("Btu", 52752792631.0 / 50000000.0, exports.Joule);
exports.KiloBtu = unit_prefix_1.Kilo("KiloBtu", exports.Btu);
exports.MegaBtu = unit_prefix_1.Mega("MegaBtu", exports.Btu);
exports.Therm = Unit.timesNumber("Therm", 100000, exports.Btu);
//# sourceMappingURL=energy.js.map