"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitDivide = require("../unit-divide");
var base_units_1 = require("./base-units");
var dimensionless_1 = require("./dimensionless");
var duration_1 = require("./duration");
// tslint:disable:variable-name
/**
 * The derived unit for frequency ( <code>Hz</code> ).
 * A unit of frequency equal to one cycle per second. After Heinrich Rudolf Hertz (1857-1894),
 * German physicist who was the first to produce radio waves artificially.
 */
exports.Hertz = UnitDivide.dimentionlessByDuration("Hertz", dimensionless_1.One, base_units_1.Second);
/**
 * The derived unit for activity of a radionuclide ( <code>Bq</code> ).
 * One becquerel is the radiation caused by one disintegration per second.
 * It is named after the French physicist, Antoine-Henri Becquerel (1852-1908).
 */
exports.Becquerel = UnitDivide.dimentionlessByDuration("Becquerel", dimensionless_1.One, base_units_1.Second);
// Frequency
exports.RevolutionsPerMinute = UnitDivide.dimentionlessByDuration("RevolutionsPerMinute", dimensionless_1.One, duration_1.Minute);
exports.RevolutionsPerHour = UnitDivide.dimentionlessByDuration("RevolutionsPerHour", dimensionless_1.One, duration_1.Hour);
//# sourceMappingURL=frequency.js.map