"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitDivide = require("../unit-divide");
var Unit = require("../unit");
var base_units_1 = require("./base-units");
var energy_1 = require("./energy");
var unit_prefix_1 = require("../unit-prefix");
// tslint:disable:variable-name
/**
 * The derived unit for power, radiant, flux ( <code>W</code> ).
 * One watt is equal to one joule per second.
 * It is named after the British scientist James Watt (1736-1819).
 */
exports.Watt = UnitDivide.energyByDuration("Watt", energy_1.Joule, base_units_1.Second);
// Power
exports.KiloWatt = unit_prefix_1.Kilo("KiloWatt", exports.Watt);
exports.MegaWatt = unit_prefix_1.Mega("MegaWatt", exports.Watt);
exports.GigaWatt = unit_prefix_1.Giga("GigaWatt", exports.Watt);
exports.BtuPerHour = Unit.divideNumber("BtuPerHour", 3600.0, Unit.timesNumber("", 52752792631.0 / 50000000.0, exports.Watt));
exports.TonCooling = Unit.timesNumber("TonCooling", 12000.0, exports.BtuPerHour);
exports.KiloBtuPerHour = unit_prefix_1.Kilo("KiloBtuPerHour", exports.BtuPerHour);
exports.HorsePower = Unit.timesNumber("HorsePower", 745.699872, exports.Watt);
exports.VoltAmpere = Unit.createAlternate("VoltAmpere", "VA", exports.Watt);
//# sourceMappingURL=power.js.map