"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitDivide = require("../unit-divide");
var Unit = require("../unit");
var force_1 = require("./force");
var area_1 = require("./area");
var unit_prefix_1 = require("../unit-prefix");
// tslint:disable:variable-name
/**
 * The derived unit for pressure, stress ( <code>Pa</code> ).
 * One pascal is equal to one newton per square meter.
 * It is named after the French philosopher and mathematician Blaise Pascal (1623-1662).
 */
exports.Pascal = UnitDivide.forceByArea("Pascal", force_1.Newton, area_1.SquareMeter);
// Pressure
exports.KiloPascal = unit_prefix_1.Kilo("KiloPascal", exports.Pascal);
exports.HectoPascal = unit_prefix_1.Hecto("HectoPascal", exports.Pascal);
exports.NewtonPerSquareMeter = UnitDivide.forceByArea("NewtonPerSquareMeter", force_1.Newton, area_1.SquareMeter);
exports.PoundForcePerSquareInch = Unit.divideNumber("PoundForcePerSquareInch", 1290320000.0, Unit.timesNumber("", 8896443230521.0, exports.Pascal));
exports.PoundForcePerSquareFoot = Unit.timesNumber("PoundForcePerSquareFoot", 144.0, exports.PoundForcePerSquareInch);
exports.DeciPascal = unit_prefix_1.Deci("DeciPascal", exports.Pascal);
// http://www.wolframalpha.com/input/?i=psi and select 'Show exact conversions'
exports.InchOfMercury = Unit.divideNumber("InchOfMercury", 152.0, Unit.timesNumber("", 514731.0, exports.Pascal));
// http://www.wolframalpha.com/input/?i=inHg and select 'Show exact conversions'
exports.InchOfWaterColumn = Unit.timesNumber("InchOfWaterColumn", 249.0889, exports.Pascal);
// http://www.wolframalpha.com/input/?i=inWC
exports.FeetOfWaterColumn = Unit.timesNumber("FeetOfWaterColumn", 2989.067, exports.Pascal);
exports.Bar = Unit.timesNumber("Bar", 100000.0, exports.Pascal);
exports.MilliBar = unit_prefix_1.Milli("MilliBar", exports.Bar);
//# sourceMappingURL=pressure.js.map