import * as UnitTimes from "../unit-times";
import * as Unit from "../unit";
import { Meter } from "./base-units";
import { Newton } from "./force";
import { Kilo, Mega } from "../unit-prefix";
// tslint:disable:variable-name
/**
 * The derived unit for energy, work, quantity of heat ( <code>J</code> ).
 * One joule is the amount of work done when an applied force of 1 newton moves
 * through a distance of 1 metre in the direction of the force.
 * It is named after the English physicist James Prescott Joule (1818-1889).
 */
export var Joule = UnitTimes.forceByLength("Joule", Newton, Meter);
// Energy
export var NewtonMeter = UnitTimes.forceByLength("NewtonMeter", Newton, Meter);
export var Kilojoule = Kilo("Kilojoule", Joule);
export var Megajoule = Mega("Megajoule", Joule);
export var Btu = Unit.timesNumber("Btu", 52752792631.0 / 50000000.0, Joule);
export var KiloBtu = Kilo("KiloBtu", Btu);
export var MegaBtu = Mega("MegaBtu", Btu);
export var Therm = Unit.timesNumber("Therm", 100000, Btu);
//# sourceMappingURL=energy.js.map